﻿using System;
using System.Collections.Generic;
using System.Text;
using Xamarin.Forms;

namespace FactPDA.Views
{
    public class DateMaskBehavior : Behavior<Entry>
    {
        /* 사용법
        <Entry Grid.Row="9" Grid.Column="3" x:Name="txtEND_DT" Text="{Binding strEND_DT}" Keyboard="Numeric">
            <Entry.Behaviors>
                <factv:DateMaskBehavior x:Name="strEND_DT_Mask" />
                <factv:EntryLengthValidator MaxLength="10"/>
            </Entry.Behaviors>
        </Entry>
        */

        public static DateMaskBehavior Instance = new DateMaskBehavior();

        // Attaches when the page is first created.  
        protected override void OnAttachedTo(Entry entry)
        {
            entry.TextChanged += OnEntryTextChanged;
            base.OnAttachedTo(entry);
        }

        // Detaches when the page is destroyed.  
        protected override void OnDetachingFrom(Entry entry)
        {
            entry.TextChanged -= OnEntryTextChanged;
            base.OnDetachingFrom(entry);
        }

        private void OnEntryTextChanged(object sender, TextChangedEventArgs args)
        {
            if (!string.IsNullOrWhiteSpace(args.NewTextValue))
            {
                // If the new value is longer than the old value, the user is  
                if (args.OldTextValue != null && args.NewTextValue.Length < args.OldTextValue.Length)
                    return;

                var value = args.NewTextValue;

                if (value.Length == 4)
                {
                    ((Entry)sender).Text += "-";
                    return;
                }

                if (value.Length == 7)
                {
                    ((Entry)sender).Text += "-";
                    return;
                }

                ((Entry)sender).Text = args.NewTextValue;
            }
        }
    }
}
