﻿using System;
using System.Collections.Generic;
using System.Text;
using Xamarin.Forms;

namespace FactPDA.Views
{
    public class EntryLengthValidator : Behavior<Entry>
    {
        /* 사용법
        <Entry Grid.Row="9" Grid.Column="3" x:Name="txtEND_DT" Text="{Binding strEND_DT}" Keyboard="Numeric">
            <Entry.Behaviors>
                <factv:DateMaskBehavior x:Name="strEND_DT_Mask" />
                <factv:EntryLengthValidator MaxLength="10"/>
            </Entry.Behaviors>
        </Entry>
        */          
         
        public int MaxLength { get; set; }
        public int MinLength { get; set; } = 0;

        protected override void OnAttachedTo(Entry bindable)
        {
            base.OnAttachedTo(bindable);
            bindable.TextChanged += OnEntryTextChanged;
        }

        protected override void OnDetachingFrom(Entry bindable)
        {
            base.OnDetachingFrom(bindable);
            bindable.TextChanged -= OnEntryTextChanged;
        }

        void OnEntryTextChanged(object sender, TextChangedEventArgs e)
        {
            var entry = (Entry)sender;

            // if Entry text is longer than valid length  
            if (entry.Text.Length > this.MaxLength)
            {
                string entryText = entry.Text;

                entryText = entryText.Remove(entryText.Length - 1); // remove last char  

                entry.Text = entryText;
            }

            if (MinLength > 0)
                if (entry.Text.Length < this.MinLength)
                {
                    ((Entry)sender).TextColor = Color.Red;
                }
                else
                    ((Entry)sender).TextColor = Color.Black;
        }
    }
}
